@@ -58,21 +58,6 @@ methods that do not yet form part of official WWW::Curl distribution.
 use strict;
 use warnings;
 
-use Carp qw(croak);
-
-our $VERSION = 4.15;
-
-=for Pod::Coverage
-VERSION
-=cut
-
-# Dirty hack so Test::ConsistentVersion passes
-sub VERSION {
-	return (caller)[0] eq 'Test::ConsistentVersion'
-		? '0.58_3'
-		: $VERSION;
-}
-
 my %packages = (
 #MODULES#
 );
@@ -81,8 +66,7 @@ my $start = tell *DATA;
 unshift @INC, sub {
 	my $pkg = $packages{ $_[1] };
 	return unless defined $pkg;
-	## no critic (RequireUseOfExceptions)
-	open(my $fh, '<&', *DATA) or croak "can't read from __DATA__";
+	open my $fh, '<&', *DATA;
 	seek $fh, $start + $pkg, 0;
 	return $fh;
 };
@@ -91,7 +75,7 @@ unshift @INC, sub {
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011-2015 Przemyslaw Iskra <sparky at pld-linux.org>.
+Copyright (c) 2011 Przemyslaw Iskra <sparky at pld-linux.org>.
 
 You may opt to use, copy, modify, merge, publish, distribute and/or sell
 copies of the Software, and permit persons to whom the Software is furnished
